@@ -2,6 +2,8 @@
 from __future__ import annotations
 
 import copy
+import functools
+import operator
 import uuid
 from dataclasses import asdict, make_dataclass
 from typing import TYPE_CHECKING, Any, TypeVar, cast
@@ -14,7 +16,7 @@ from .basic_types import (
     Event,
     Immutable,
     InitAction,
-    is_reducer_result,
+    is_complete_reducer_result,
 )
 
 if TYPE_CHECKING:
@@ -96,7 +98,7 @@ def combine_reducers(
                         {
                             key_: (
                                 reducer_result.state
-                                if is_reducer_result(reducer_result)
+                                if is_complete_reducer_result(reducer_result)
                                 else reducer_result
                             )
                             if key == key_
@@ -107,12 +109,12 @@ def combine_reducers(
                 )
                 result_actions += (
                     reducer_result.actions or []
-                    if is_reducer_result(reducer_result)
+                    if is_complete_reducer_result(reducer_result)
                     else []
                 )
                 result_events += (
                     reducer_result.events or []
-                    if is_reducer_result(reducer_result)
+                    if is_complete_reducer_result(reducer_result)
                     else []
                 )
             elif (
@@ -148,20 +150,22 @@ def combine_reducers(
         result_state = state_class(
             _id=_id,
             **{
-                key: result.state if is_reducer_result(result) else result
+                key: result.state if is_complete_reducer_result(result) else result
                 for key, result in reducers_results.items()
             },
         )
-        result_actions += sum(
+        result_actions += functools.reduce(
+            operator.iadd,
             [
-                result.actions or [] if is_reducer_result(result) else []
+                result.actions or [] if is_complete_reducer_result(result) else []
                 for result in reducers_results.values()
             ],
             [],
         )
-        result_events += sum(
+        result_events += functools.reduce(
+            operator.iadd,
             [
-                result.events or [] if is_reducer_result(result) else []
+                result.events or [] if is_complete_reducer_result(result) else []
                 for result in reducers_results.values()
             ],
             [],
